diff --git a/interface/resources/images/about-opus.png b/interface/resources/images/about-opus.png
new file mode 100644
index 0000000000..57924b070f
Binary files /dev/null and b/interface/resources/images/about-opus.png differ
diff --git a/interface/resources/images/about-projectathena.png b/interface/resources/images/about-projectathena.png
new file mode 100644
index 0000000000..ae2d2bcd06
Binary files /dev/null and b/interface/resources/images/about-projectathena.png differ
diff --git a/interface/resources/qml/hifi/dialogs/TabletAboutDialog.qml b/interface/resources/qml/hifi/dialogs/TabletAboutDialog.qml
index 91e40aa608..2be66442ce 100644
--- a/interface/resources/qml/hifi/dialogs/TabletAboutDialog.qml
+++ b/interface/resources/qml/hifi/dialogs/TabletAboutDialog.qml
@@ -25,7 +25,7 @@ Rectangle {
Image {
sourceSize.width: 295
sourceSize.height: 75
- source: "../../../images/about-highfidelity.png"
+ source: "../../../images/about-projectathena.png"
}
Item { height: 30; width: 1 }
Column {
@@ -45,7 +45,7 @@ Rectangle {
}
Item { height: 10; width: 1 }
RalewayRegular {
- text: "An open-source virtual reality platform."
+ text: "An open source virtual reality platform."
size: 20
color: "white"
}
@@ -56,9 +56,9 @@ Rectangle {
text: "Project Athena Github."
size: 20
onLinkActivated: {
- HiFiAbout.openUrl("https:/github.com/kasenvr/hifi-community");
+ HiFiAbout.openUrl("https:/github.com/kasenvr/project-athena");
}
-
+
}
Item { height: 40; width: 1 }
Row {
@@ -93,21 +93,35 @@ Rectangle {
anchors.verticalCenter: parent.verticalCenter
}
}
+ Row {
+ spacing: 5
+ Image {
+ sourceSize.width: 34
+ sourceSize.height: 25
+ source: "../../../images/about-opus.png"
+ MouseArea {
+ anchors.fill: parent
+ onClicked: {
+ HiFiAbout.openUrl("http://opus-codec.org/");
+ }
+ }
+ }
+ RalewayRegular {
+ color: "white"
+ text: "Built using the Opus codec."
+ size: 12
+ anchors.verticalCenter: parent.verticalCenter
+ }
+ }
Item { height: 20; width: 1 }
RalewayRegular {
- textFormat: Text.StyledText
- linkColor: "#00B4EF"
color: "white"
- property string link: "https://eos.io/"
- text: "Blockchain technology from EOS."
+ text: "© 2019 - 2020 Project Athena Contributors."
size: 14
- onLinkActivated: {
- HiFiAbout.openUrl(link);
- }
}
RalewayRegular {
color: "white"
- text: "© 2012 - 2019 High Fidelity, Inc.. All rights reserved."
+ text: "© 2012 - 2019 High Fidelity, Inc. All rights reserved."
size: 14
}
RalewayRegular {
diff --git a/interface/src/Menu.cpp b/interface/src/Menu.cpp
index 1be67ef188..b0e5bbe8de 100644
--- a/interface/src/Menu.cpp
+++ b/interface/src/Menu.cpp
@@ -768,30 +768,30 @@ Menu::Menu() {
// Help/Application menu ----------------------------------
MenuWrapper * helpMenu = addMenu("Help");
- // Help > About High Fidelity
- action = addActionToQMenuAndActionHash(helpMenu, "About High Fidelity");
+ // Help > About Project Athena
+ action = addActionToQMenuAndActionHash(helpMenu, "About Project Athena");
connect(action, &QAction::triggered, [] {
qApp->showDialog(QString("hifi/dialogs/AboutDialog.qml"),
QString("hifi/dialogs/TabletAboutDialog.qml"), "AboutDialog");
});
helpMenu->addSeparator();
// Help > HiFi Docs
action = addActionToQMenuAndActionHash(helpMenu, "Online Documentation");
connect(action, &QAction::triggered, qApp, [] {
- QDesktopServices::openUrl(QUrl("https://docs.highfidelity.com/"));
+ QDesktopServices::openUrl(QUrl("https://docs.projectathena.dev/"));
});
- // Help > HiFi Forum
- action = addActionToQMenuAndActionHash(helpMenu, "Online Forums");
+ // Help > Athena Forum
+ /* action = addActionToQMenuAndActionHash(helpMenu, "Online Forums");
connect(action, &QAction::triggered, qApp, [] {
QDesktopServices::openUrl(QUrl("https://forums.highfidelity.com/"));
- });
+ }); */
// Help > Scripting Reference
action = addActionToQMenuAndActionHash(helpMenu, "Online Script Reference");
connect(action, &QAction::triggered, qApp, [] {
- QDesktopServices::openUrl(QUrl("https://docs.highfidelity.com/api-reference"));
+ QDesktopServices::openUrl(QUrl("https://apidocs.projectathena.dev/"));
});
addActionToQMenuAndActionHash(helpMenu, "Controls Reference", 0, qApp, SLOT(showHelp()));
@@ -801,13 +801,13 @@ Menu::Menu() {
// Help > Release Notes
action = addActionToQMenuAndActionHash(helpMenu, "Release Notes");
connect(action, &QAction::triggered, qApp, [] {
- QDesktopServices::openUrl(QUrl("https://docs.highfidelity.com/release-notes.html"));
+ QDesktopServices::openUrl(QUrl("https://docs.projectathena.dev/release-notes.html"));
});
// Help > Report a Bug!
action = addActionToQMenuAndActionHash(helpMenu, "Report a Bug!");
connect(action, &QAction::triggered, qApp, [] {
- QDesktopServices::openUrl(QUrl("https://github.com/kasenvr/hifi-community/issues"));
+ QDesktopServices::openUrl(QUrl("https://github.com/kasenvr/project-athena/issues"));
});
}
@@ -768,30 +768,30 @@ Menu::Menu() {
});
helpMenu->addSeparator();
- // Help > HiFi Docs
+ // Help > Athena Docs
action = addActionToQMenuAndActionHash(helpMenu, "Online Documentation");
connect(action, &QAction::triggered, qApp, [] {